@@ -7,7 +7,7 @@
 -- |
 --  Module      :  Turtle
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2013, 2014, 2018, 2019 Douglas Burke
+--                 2011, 2012, 2013, 2014, 2018, 2019, 2020 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -94,7 +94,6 @@ import Swish.RDF.Vocabulary (rdfType, rdfNil)
 import Control.Applicative ((<$>))
 #endif
 
-import Control.Monad (liftM)
 import Control.Monad.State (State, modify, gets, runState)
 
 import Data.Char (isDigit)
@@ -267,7 +266,7 @@ insertBnode SubjContext lbl = do
   flag <- hasMore props
   if flag
     then do
-      txt <- (`mappend` "\n") `liftM` formatProperties lbl ""
+      txt <- (`mappend` "\n") `fmap` formatProperties lbl ""
       return $ mconcat ["[] ", txt]
     else error $ "Internal error: expected properties with label: " ++ show lbl
 
@@ -363,7 +362,7 @@ formatLabel lctxt lab@(Blank (_:_)) = do
 formatLabel ctxt (Res sn)
   | ctxt == PredContext && sn == rdfType = return "a"
   | ctxt == ObjContext  && sn == rdfNil  = return "()"
-  | otherwise = formatScopedName sn <$> gets prefixes
+  | otherwise = gets (formatScopedName sn . prefixes)
 
 formatLabel _ (Lit lit) = return $ formatPlainLit lit
 formatLabel _ (LangLit lit lcode) = return $ formatLangLit lit lcode
@@ -382,7 +381,7 @@ mapBlankNode = mapBlankNode_ _nodeGen
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013, 2014, 2018 Douglas Burke
+--    2011, 2012, 2013, 2014, 2018, 2019, 2020 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
